/*-
 * %%----------------------------------------------------------------------------------------------
 * Solidify Framework - Solidify Index - IndexMetadataController.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

package ch.unige.solidify.controller.index;

import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import ch.unige.solidify.IndexConstants;
import ch.unige.solidify.IndexUrlPath;
import ch.unige.solidify.SolidifyConstants;
import ch.unige.solidify.controller.AssociationIndexReadOnlyController;
import ch.unige.solidify.controller.IndexController;
import ch.unige.solidify.model.index.IndexMetadata;
import ch.unige.solidify.model.index.IndexSettings;
import ch.unige.solidify.security.TrustedUserPermissions;
import ch.unige.solidify.service.CompositeNoSqlResourceService;
import ch.unige.solidify.service.IndexResourceService;

@TrustedUserPermissions
@RestController
@ConditionalOnBean(IndexController.class)
@RequestMapping(IndexUrlPath.INDEX_INDEX + SolidifyConstants.URL_PARENT_ID + IndexConstants.METADATA)
public class IndexMetadataController extends AssociationIndexReadOnlyController<IndexSettings, IndexMetadata> {

  public IndexMetadataController(
          CompositeNoSqlResourceService<IndexSettings> noSqlResourceService,
          IndexResourceService<IndexSettings, IndexMetadata> indexSubResourceService) {
    super(noSqlResourceService, indexSubResourceService);
  }

  @Override
  protected String getIndex() {
    return null;
  }

  @Override
  protected Class<IndexSettings> getMainResourceClass() {
    return IndexSettings.class;
  }

  @Override
  protected Class<IndexMetadata> getSubResourceClass() {
    return IndexMetadata.class;
  }

}
